Heart Rate Variability Analysis Package
===============================

version number: 0.1.1
author: Rhenan Bartels

Overview
--------

A python package for heart rate variability analysis

Installation / Usage
--------------------

To install use pip:

    $ pip install hrv


Or clone the repo:

    $ git clone https://github.com/rhenanbartels/hrv.git
    $ python setup.py install
    
Contributing
------------

TBD

Example
-------

TBD